==> nextcloud-27.1.11.tgz: nextcloud/apps/systemtags/l10n/pt_BR.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "A tag de sistema %1$s foi adicionado pelo sistema",
    "Added system tag {systemtag}" : "Adicionada a etiqueta de sistema {systemtag}",
    "Added system tag %1$s" : "Adicionada a etiqueta de sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s adicionou a etiqueta de sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} adicionou a etiqueta de sistema {systemtag}",
    "System tag %1$s removed by the system" : "A tag de sistema %1$s foi removida pelo sistema",
    "Removed system tag {systemtag}" : "Etiqueta de sistema excluída {systemtag}",
    "Removed system tag %1$s" : "Excluída a etiqueta da sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$s excluiu a etiqueta de sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} excluiu a etiqueta de sistema {systemtag}",
    "You created system tag %1$s" : "Você criou a etiqueta de sistema %1$s",
    "You created system tag {systemtag}" : "Você criou a etiqueta de sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s criou a etiqueta de sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} criou a etiqueta de sistema {systemtag}",
    "You deleted system tag %1$s" : "Você excluiu a etiqueta de sistema %1$s",
    "You deleted system tag {systemtag}" : "Você excluiu a etiqueta de sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s excluiu a etiqueta de sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} excluiu a etiqueta de sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Você atualizou a etiqueta de sistema %2$s para %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Você atualizou a etiqueta de sistema de {oldsystemtag} para {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s atualizou a etiqueta de sistema %3$s para %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} atualizou a etiqueta de sistema de {oldsystemtag} para {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "A tag de sistema %2$s foi adicionado %1$s pelo sistema",
    "System tag {systemtag} was added to {file} by the system" : "A tag do sistema {systemtag} foi adicionada ao {file} pelo sistema",
    "You added system tag %2$s to %1$s" : "Você adicionou a etiqueta de sistema %2$s para %1$s",
    "You added system tag {systemtag} to {file}" : "Você adicionou a etiqueta de sistema {systemtag} para {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s adicionou a etiqueta de sistema %3$s para %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} adicionou a etiqueta de sistema {systemtag} para {file}",
    "System tag %2$s was removed from %1$s by the system" : "A tag de sistema %2$s foi removida de %1$s pelo sistema",
    "System tag {systemtag} was removed from {file} by the system" : "A tag de sistema {systemtag} foi removida de {file} pelo sistema",
    "You removed system tag %2$s from %1$s" : "Você excluiu a etiqueta de sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Você excluiu a etiqueta de sistema {systemtag} de {file} ",
    "%1$s removed system tag %3$s from %2$s" : "%1$s excluiu a etiqueta de sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} excluiu a etiqueta de sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restrito)",
    "%s (invisible)" : "%s (invisível)",
    "<strong>System tags</strong> for a file have been modified" : "As <strong>etiquetas de sistema</strong> para um arquivo foram modificadas",
    "Tags" : "Etiquetas",
    "All tagged %s …" : "Todos os %s marcados …",
    "tagged %s" : "marcado %s",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Collaborative tagging functionality which shares tags among people." : "Funcionalidade de marcação colaborativa que compartilha etiquetas entre pessoas.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidade de marcação colaborativa que compartilha etiquetas entre pessoas. Ótimo para equipes. \n\t(Se você for um provedor com instalação multilocatária, é aconselhável desativar este aplicativo, pois as etiquetas são compartilhadas.)",
    "Create or edit tags" : "Criar ou editar etiquetas",
    "Search for a tag to edit" : "Procure uma etiqueta para editar",
    "Collaborative tags …" : "Etiquetas colaborativas…",
    "No tags to select" : "Nenhuma etiqueta para selecionar",
    "Tag name" : "Nome da etiqueta",
    "Tag level" : "Nível de etiqueta",
    "Create" : "Criar",
    "Update" : "Atualizar",
    "Delete" : "Excluir",
    "Reset" : "Redefinir",
    "Loading …" : "Carregando …",
    "Public" : "Público",
    "Restricted" : "Restrito",
    "Invisible" : "Invisível",
    "Created tag" : "Etiqueta criada",
    "Failed to create tag" : "Falha ao criar etiqueta",
    "Updated tag" : "Etiqueta atualizada",
    "Failed to update tag" : "Falha ao atualizar a etiqueta",
    "Deleted tag" : "Etiqueta excluída",
    "Failed to delete tag" : "Falha ao excluir etiqueta",
    "Loading collaborative tags …" : "Carregando etiquetas,s colaborativas…",
    "Search or create collaborative tags" : "Pesquise ou crie etiquetas colaborativas",
    "No tags to select, type to create a new tag" : "Nenhuma etiqueta para selecionar, digite para criar uma nova etiqueta",
    "Failed to load tags" : "Erro ao carregar rótulos",
    "Failed to load selected tags" : "Falha ao carregar as etiquetas selecionadas",
    "Failed to select tag" : "Falha ao selecionar etiqueta",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Etiquetas colaborativas estão disponíveis para todos os usuários. As etiquetas restritas são visíveis para os usuários, mas não podem ser atribuídas por eles. Etiquetas invisíveis são para uso interno, já que os usuários não podem vê-las ou atribuí-las.",
    "This file has the tag {tag}" : "Este arquivo tem a tag {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Este arquivo tem as etiquetas {firstTags} e {lastTag}",
    "List of tags and their associated files and folders." : "Lista de etiquetas e seus arquivos e pastas associados.",
    "No tags found" : "Nenhuma etiqueta encontrada",
    "Tags you have created will show up here." : "Asetiquetas que você criou aparecerão aqui.",
    "Failed to load last used tags" : "Falha ao carregar as últimas etiquetas usadas",
    "Missing \"Content-Location\" header" : "Cabeçalho \"Conteúdo-Localização\" ausente",
    "Failed to load tags for file" : "Falha ao carregar etiquetas para arquivo",
    "Failed to set tag for file" : "Falha ao definir etiqueta para arquivo",
    "Failed to delete tag for file" : "Falha ao excluir etiqueta do arquivo",
    "Tag name is empty" : "O nome da etiqueta está vazia",
    "Select tag …" : "Selecionar etiqueta...",
    "Collaborative tagging functionality which shares tags among users." : "Funcionalidade de marcação colaborativa que compartilha rótulos entre usuários.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidade de marcação colaborativa que compartilha rótulos entre usuários. Ótimo para equipes.\n\t(Se você for um provedor de uma instalação de multilocação, é aconselhável desativar isso, pois os rótulos são compartilhados.)",
    "Tagged files" : "Arquivos etiquetados",
    "Select tags to filter by" : "Selecione etiquetas a filtrar",
    "Please select tags to filter by" : "Por favor selecione etiquetas a filtrar",
    "No files found for the selected tags" : "Nenhum arquivo encontrado para as etiquetas selecionadas",
    "Create a new tag" : "Criar uma nova etiqueta",
    "Name" : "Nome",
    "No files in here" : "Nenhum arquivo aqui",
    "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
    "Size" : "Tamanho",
    "Modified" : "Modificado"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-29.0.5.tgz: nextcloud/apps/systemtags/l10n/pt_BR.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "A tag de sistema %1$s foi adicionado pelo sistema",
    "Added system tag {systemtag}" : "Adicionada a etiqueta de sistema {systemtag}",
    "Added system tag %1$s" : "Adicionada a etiqueta de sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s adicionou a etiqueta de sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} adicionou a etiqueta de sistema {systemtag}",
    "System tag %1$s removed by the system" : "A tag de sistema %1$s foi removida pelo sistema",
    "Removed system tag {systemtag}" : "Etiqueta de sistema excluída {systemtag}",
    "Removed system tag %1$s" : "Excluída a etiqueta da sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$s excluiu a etiqueta de sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} excluiu a etiqueta de sistema {systemtag}",
    "You created system tag %1$s" : "Você criou a etiqueta de sistema %1$s",
    "You created system tag {systemtag}" : "Você criou a etiqueta de sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s criou a etiqueta de sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} criou a etiqueta de sistema {systemtag}",
    "You deleted system tag %1$s" : "Você excluiu a etiqueta de sistema %1$s",
    "You deleted system tag {systemtag}" : "Você excluiu a etiqueta de sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s excluiu a etiqueta de sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} excluiu a etiqueta de sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Você atualizou a etiqueta de sistema %2$s para %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Você atualizou a etiqueta de sistema de {oldsystemtag} para {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s atualizou a etiqueta de sistema %3$s para %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} atualizou a etiqueta de sistema de {oldsystemtag} para {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "A tag de sistema %2$s foi adicionado %1$s pelo sistema",
    "System tag {systemtag} was added to {file} by the system" : "A tag do sistema {systemtag} foi adicionada ao {file} pelo sistema",
    "You added system tag %2$s to %1$s" : "Você adicionou a etiqueta de sistema %2$s para %1$s",
    "You added system tag {systemtag} to {file}" : "Você adicionou a etiqueta de sistema {systemtag} para {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s adicionou a etiqueta de sistema %3$s para %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} adicionou a etiqueta de sistema {systemtag} para {file}",
    "System tag %2$s was removed from %1$s by the system" : "A tag de sistema %2$s foi removida de %1$s pelo sistema",
    "System tag {systemtag} was removed from {file} by the system" : "A tag de sistema {systemtag} foi removida de {file} pelo sistema",
    "You removed system tag %2$s from %1$s" : "Você excluiu a etiqueta de sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Você excluiu a etiqueta de sistema {systemtag} de {file} ",
    "%1$s removed system tag %3$s from %2$s" : "%1$s excluiu a etiqueta de sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} excluiu a etiqueta de sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restrito)",
    "%s (invisible)" : "%s (invisível)",
    "<strong>System tags</strong> for a file have been modified" : "As <strong>etiquetas de sistema</strong> para um arquivo foram modificadas",
    "Files" : "Arquivos",
    "Tags" : "Etiquetas",
    "All tagged %s …" : "Todos os %s marcados …",
    "tagged %s" : "marcado %s",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Collaborative tagging functionality which shares tags among people." : "Funcionalidade de marcação colaborativa que compartilha etiquetas entre pessoas.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidade de marcação colaborativa que compartilha etiquetas entre pessoas. Ótimo para equipes. \n\t(Se você for um provedor com instalação multilocatária, é aconselhável desativar este aplicativo, pois as etiquetas são compartilhadas.)",
    "Create or edit tags" : "Criar ou editar etiquetas",
    "Search for a tag to edit" : "Procure uma etiqueta para editar",
    "Collaborative tags …" : "Etiquetas colaborativas…",
    "No tags to select" : "Nenhuma etiqueta para selecionar",
    "Tag name" : "Nome da etiqueta",
    "Tag level" : "Nível de etiqueta",
    "Create" : "Criar",
    "Update" : "Atualizar",
    "Delete" : "Excluir",
    "Reset" : "Redefinir",
    "Loading …" : "Carregando …",
    "Public" : "Público",
    "Restricted" : "Restrito",
    "Invisible" : "Invisível",
    "Created tag" : "Etiqueta criada",
    "Failed to create tag" : "Falha ao criar etiqueta",
    "Updated tag" : "Etiqueta atualizada",
    "Failed to update tag" : "Falha ao atualizar a etiqueta",
    "Deleted tag" : "Etiqueta excluída",
    "Failed to delete tag" : "Falha ao excluir etiqueta",
    "Loading collaborative tags …" : "Carregando etiquetas,s colaborativas…",
    "Search or create collaborative tags" : "Pesquise ou crie etiquetas colaborativas",
    "No tags to select, type to create a new tag" : "Nenhuma etiqueta para selecionar, digite para criar uma nova etiqueta",
    "Failed to load tags" : "Erro ao carregar rótulos",
    "Failed to load selected tags" : "Falha ao carregar as etiquetas selecionadas",
    "Failed to select tag" : "Falha ao selecionar etiqueta",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Etiquetas colaborativas estão disponíveis para todos os usuários. As etiquetas restritas são visíveis para os usuários, mas não podem ser atribuídas por eles. Etiquetas invisíveis são para uso interno, já que os usuários não podem vê-las ou atribuí-las.",
    "Assigned collaborative tags" : "Etiquetas colaborativas atribuídas",
    "Open in Files" : "Abrir em arquivos",
    "List of tags and their associated files and folders." : "Lista de etiquetas e seus arquivos e pastas associados.",
    "No tags found" : "Nenhuma etiqueta encontrada",
    "Tags you have created will show up here." : "Asetiquetas que você criou aparecerão aqui.",
    "Failed to load last used tags" : "Falha ao carregar as últimas etiquetas usadas",
    "Missing \"Content-Location\" header" : "Cabeçalho \"Conteúdo-Localização\" ausente",
    "Failed to load tags for file" : "Falha ao carregar etiquetas para arquivo",
    "Failed to set tag for file" : "Falha ao definir etiqueta para arquivo",
    "Failed to delete tag for file" : "Falha ao excluir etiqueta do arquivo",
    "Collaborative tagging functionality which shares tags among users." : "Funcionalidade de marcação colaborativa que compartilha rótulos entre usuários.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidade de marcação colaborativa que compartilha rótulos entre usuários. Ótimo para equipes.\n\t(Se você for um provedor de uma instalação de multilocação, é aconselhável desativar isso, pois os rótulos são compartilhados.)",
    "This file has the tag {tag}" : "Este arquivo tem a tag {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Este arquivo tem as etiquetas {firstTags} e {lastTag}",
    "No files in here" : "Nenhum arquivo aqui",
    "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
